@@ -1,10 +1,18 @@
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
+
 #include <sirius.hpp>
 #include <testing.hpp>
 #include "symmetry/crystal_symmetry.hpp"
 
 using namespace sirius;
 
-void
+int
 test_sym(cmd_args const& args__)
 {
     auto pw_cutoff = args__.value<double>("pw_cutoff", 10);
@@ -95,7 +103,7 @@ test_sym(cmd_args const& args__)
                         for (int ig = 0; ig < kset_nosym.get<double>(ik1)->num_gkvec(); ig++) {
                             double w = 1.0 / (1.0 + kset_nosym.get<double>(ik1)
                                                             ->gkvec()
-                                                            .gkvec_cart<index_domain_t::global>(ig)
+                                                            .gkvec_cart(gvec_index_t::global(ig))
                                                             .length());
                             auto z1  = phi_nosym[ik1].pw_coeffs(ig, wf::spin_index(0), wf::band_index(m1 + ib));
                             auto z2  = phi_nosym[ik1].pw_coeffs(ig, wf::spin_index(0), wf::band_index(m2 + ib));
@@ -155,7 +163,7 @@ test_sym(cmd_args const& args__)
                             double w =
                                     1.0 /
                                     (1.0 +
-                                     kset_sym.get<double>(ik)->gkvec().gkvec_cart<index_domain_t::global>(ig).length());
+                                     kset_sym.get<double>(ik)->gkvec().gkvec_cart(gvec_index_t::global(ig)).length());
                             auto z1 = phi1.pw_coeffs(ig, wf::spin_index(0), wf::band_index(m1 + ib));
                             auto z2 = phi1.pw_coeffs(ig, wf::spin_index(0), wf::band_index(m2 + ib));
                             dm1(m1, m2, ia) += std::conj(z1) * z2 * w;
@@ -204,6 +212,7 @@ test_sym(cmd_args const& args__)
             }
         }
     }
+    return 0;
 }
 
 int
@@ -215,18 +224,8 @@ main(int argn, char** argv)
                           {"gk_cutoff=", "(double) plane-wave cutoff for wave-functions"},
                   });
 
-    if (args.exist("help")) {
-        printf("Usage: %s [options]\n", argv[0]);
-        args.print_help();
-        return 0;
-    }
-
     sirius::initialize(1);
-    test_sym(args);
-    int rank = mpi::Communicator::world().rank();
+    int result = call_test("test_sym", test_sym, args);
     sirius::finalize();
-    if (rank == 0) {
-        const auto timing_result = global_rtgraph_timer.process();
-        std::cout << timing_result.print();
-    }
+    return result;
 }
