@@ -1,11 +1,20 @@
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
+
 #include <sirius.hpp>
+#include <testing.hpp>
 
 using namespace sirius;
 
 template <typename T, typename F>
-void
-test_wf_trans(la::BLACS_grid const& blacs_grid__, double cutoff__, int num_bands__, int bs__, int num_mag_dims__,
-              memory_t mem__)
+int
+test_wf_trans_aux(la::BLACS_grid const& blacs_grid__, double cutoff__, int num_bands__, int bs__, int num_mag_dims__,
+                  memory_t mem__)
 {
     spla::Context spla_ctx(is_host_memory(mem__) ? SPLA_PU_HOST : SPLA_PU_GPU);
 
@@ -94,12 +103,13 @@ test_wf_trans(la::BLACS_grid const& blacs_grid__, double cutoff__, int num_bands
         }
     }
     std::cout << "diff = " << diff << std::endl;
+    return 0;
 }
 
 template <typename T>
-void
-call_test(std::vector<int> mpi_grid_dims__, double cutoff__, int num_bands__, int bs__, int num_mag_dims__,
-          memory_t mem__, int repeat__)
+int
+test_wf_trans_impl(std::vector<int> mpi_grid_dims__, double cutoff__, int num_bands__, int bs__, int num_mag_dims__,
+                   memory_t mem__, int repeat__)
 {
     std::unique_ptr<la::BLACS_grid> blacs_grid;
     if (mpi_grid_dims__[0] * mpi_grid_dims__[1] == 1) {
@@ -108,55 +118,49 @@ call_test(std::vector<int> mpi_grid_dims__, double cutoff__, int num_bands__, in
         blacs_grid =
                 std::make_unique<la::BLACS_grid>(mpi::Communicator::world(), mpi_grid_dims__[0], mpi_grid_dims__[1]);
     }
+    int ierr{0};
     for (int i = 0; i < repeat__; i++) {
-        test_wf_trans<T, std::complex<double>>(*blacs_grid, cutoff__, num_bands__, bs__, num_mag_dims__, mem__);
+        ierr += test_wf_trans_aux<T, std::complex<double>>(*blacs_grid, cutoff__, num_bands__, bs__, num_mag_dims__,
+                                                           mem__);
     }
+    return ierr;
 }
 
 int
-main(int argn, char** argv)
+test_wf_trans(cmd_args const& args)
 {
-    cmd_args args;
-    args.register_key("--mpi_grid_dims=", "{int int} dimensions of MPI grid");
-    args.register_key("--cutoff=", "{double} wave-functions cutoff");
-    args.register_key("--bs=", "{int} block size");
-    args.register_key("--num_bands=", "{int} number of bands");
-    args.register_key("--num_mag_dims=", "{int} number of magnetic dimensions");
-    args.register_key("--memory_t=", "{string} type of memory");
-    args.register_key("--fp32", "use FP32 arithmetics");
-
-    args.parse_args(argn, argv);
-    if (args.exist("help")) {
-        printf("Usage: %s [options]\n", argv[0]);
-        args.print_help();
-        return 0;
-    }
     auto mpi_grid_dims = args.value("mpi_grid_dims", std::vector<int>({1, 1}));
     auto cutoff        = args.value<double>("cutoff", 8.0);
     auto bs            = args.value<int>("bs", 32);
     auto num_bands     = args.value<int>("num_bands", 100);
     auto num_mag_dims  = args.value<int>("num_mag_dims", 0);
     auto mem           = get_memory_t(args.value<std::string>("memory_t", "host"));
-
-    sirius::initialize(1);
     if (args.exist("fp32")) {
 #if defined(SIRIUS_USE_FP32)
-        call_test<float>(mpi_grid_dims, cutoff, num_bands, bs, num_mag_dims, mem, 1);
+        return test_wf_trans_impl<float>(mpi_grid_dims, cutoff, num_bands, bs, num_mag_dims, mem, 1);
 #else
         RTE_THROW("Not compiled with FP32 support");
 #endif
     } else {
-        call_test<double>(mpi_grid_dims, cutoff, num_bands, bs, num_mag_dims, mem, 1);
-    }
-
-    int my_rank = mpi::Communicator::world().rank();
-
-    sirius::finalize(1);
-
-    if (my_rank == 0) {
-        const auto timing_result = global_rtgraph_timer.process();
-        std::cout << timing_result.print();
-        // std::ofstream ofs("timers.json", std::ofstream::out | std::ofstream::trunc);
-        // ofs << timing_result.json();
+        return test_wf_trans_impl<double>(mpi_grid_dims, cutoff, num_bands, bs, num_mag_dims, mem, 1);
     }
+    return 0;
+}
+
+int
+main(int argn, char** argv)
+{
+    cmd_args args(argn, argv,
+                  {{"mpi_grid_dims=", "{int int} dimensions of MPI grid"},
+                   {"cutoff=", "{double} wave-functions cutoff"},
+                   {"bs=", "{int} block size"},
+                   {"num_bands=", "{int} number of bands"},
+                   {"num_mag_dims=", "{int} number of magnetic dimensions"},
+                   {"memory_t=", "{string} type of memory"},
+                   {"fp32", "use FP32 arithmetics"}});
+
+    sirius::initialize(1);
+    int result = call_test("test_wf_trans", test_wf_trans, args);
+    sirius::finalize(1);
+    return result;
 }
