@@ -1,3 +1,11 @@
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
+
 #include <array>
 #include "core/any_ptr.hpp"
 #include "core/memory.hpp"
@@ -6,7 +14,7 @@
 using namespace sirius;
 
 int
-run_test(cmd_args const& args)
+run_test()
 {
     void* ptr = new any_ptr(new mdarray<int, 1>({100}, get_memory_pool(memory_t::host)));
     delete static_cast<any_ptr*>(ptr);
@@ -16,7 +24,5 @@ run_test(cmd_args const& args)
 int
 main(int argn, char** argv)
 {
-    cmd_args args(argn, argv, {});
-
-    return sirius::call_test(argv[0], run_test, args);
+    return call_test(argv[0], run_test);
 }
