@@ -1,3 +1,11 @@
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
+
 #include <array>
 #include "core/cmd_args.hpp"
 #include "testing.hpp"
@@ -55,5 +63,5 @@ main(int arg, char** argv)
                    {"d1=", "(double) double parameter"},
                    {"vi1=", "(vector<int>) vector of integers"}});
 
-    return sirius::call_test(argv[0], run_test, args);
+    return call_test(argv[0], run_test, args);
 }
