@@ -1,4 +1,13 @@
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
+
 #include <sirius.hpp>
+#include <testing.hpp>
 
 /* test FFT: transform single harmonic and compare with plane wave exp(iGr) */
 
@@ -6,7 +15,7 @@ using namespace sirius;
 
 template <typename T>
 int
-test_fft(cmd_args& args, device_t pu__)
+test_fft_impl(cmd_args const& args, device_t pu__)
 {
     bool verbose = args.exist("verbose");
 
@@ -53,7 +62,7 @@ test_fft(cmd_args& args, device_t pu__)
     }
 
     for (int ig = 0; ig < gvec.num_gvec(); ig++) {
-        auto v = gvec.gvec<index_domain_t::global>(ig);
+        auto v = gvec.gvec(gvec_index_t::global(ig));
         if (mpi::Communicator::world().rank() == 0 && verbose) {
             printf("ig: %6i, gvec: %4i %4i %4i   ", ig, v[0], v[1], v[2]);
         }
@@ -105,11 +114,11 @@ test_fft(cmd_args& args, device_t pu__)
 
 template <typename T>
 int
-run_test(cmd_args& args)
+test_fft(cmd_args const& args)
 {
-    int result = test_fft<T>(args, device_t::CPU);
+    int result = test_fft_impl<T>(args, device_t::CPU);
     if (acc::num_devices()) {
-        result += test_fft<T>(args, device_t::GPU);
+        result += test_fft_impl<T>(args, device_t::GPU);
     }
     return result;
 }
@@ -117,40 +126,21 @@ run_test(cmd_args& args)
 int
 main(int argn, char** argv)
 {
-    cmd_args args;
-    args.register_key("--cutoff=", "{double} cutoff radius in G-space");
-    args.register_key("--verbose", "enable verbose output");
-    args.register_key("--fp32", "run in FP32 arithmetics");
-
-    args.parse_args(argn, argv);
-    if (args.exist("help")) {
-        printf("Usage: %s [options]\n", argv[0]);
-        args.print_help();
-        return 0;
-    }
+    cmd_args args(argn, argv,
+                  {{"cutoff=", "{double} cutoff radius in G-space"},
+                   {"verbose", "enable verbose output"},
+                   {"fp32", "run in FP32 arithmetics"}});
 
     sirius::initialize(true);
-    printf("running %-30s : ", argv[0]);
     int result{0};
     if (args.exist("fp32")) {
 #if defined(SIRIUS_USE_FP32)
-        result = run_test<float>(args);
+        result = call_test(argv[0], test_fft<float>, args);
 #else
         RTE_THROW("not compiled with FP32 support");
 #endif
     } else {
-        result = run_test<double>(args);
-    }
-    if (result) {
-        printf("\x1b[31m"
-               "Failed"
-               "\x1b[0m"
-               "\n");
-    } else {
-        printf("\x1b[32m"
-               "OK"
-               "\x1b[0m"
-               "\n");
+        result = call_test(argv[0], test_fft<double>, args);
     }
     sirius::finalize();
 
