@@ -1,12 +1,20 @@
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
+
 #include <sirius.hpp>
-#include <thread>
+#include <testing.hpp>
 
 /* test G-vectors */
 
 using namespace sirius;
 
 int
-run_test(cmd_args& args)
+test_gvec(cmd_args& args)
 {
     auto vd = args.value("dims", std::vector<int>({132, 132, 132}));
     r3::vector<int> dims(vd[0], vd[1], vd[2]);
@@ -30,32 +38,11 @@ run_test(cmd_args& args)
 int
 main(int argn, char** argv)
 {
-    cmd_args args;
-    args.register_key("--dims=", "{vector<int>} FFT dimensions");
-    args.register_key("--cutoff=", "{double} cutoff radius in G-space");
-
-    args.parse_args(argn, argv);
-    if (args.exist("help")) {
-        printf("Usage: %s [options]\n", argv[0]);
-        args.print_help();
-        return 0;
-    }
+    cmd_args args(argn, argv,
+                  {{"dims=", "{vector<int>} FFT dimensions"}, {"cutoff=", "{double} cutoff radius in G-space"}});
 
     sirius::initialize(true);
-    printf("running %-30s : ", argv[0]);
-    int result = run_test(args);
-    if (result) {
-        printf("\x1b[31m"
-               "Failed"
-               "\x1b[0m"
-               "\n");
-    } else {
-        printf("\x1b[32m"
-               "OK"
-               "\x1b[0m"
-               "\n");
-    }
+    int result = call_test(argv[0], test_gvec, args);
     sirius::finalize();
-
     return result;
 }
