@@ -6,6 +6,8 @@ export SPACK_SYSTEM_CONFIG_PATH=/user-environment/config
 
 # make sure we keep the stage direcorty
 spack config --scope=user add config:build_stage:/dev/shm/spack-stage
+# we might need to install dependencies too, e.g. nlcglib in case of API changes
+spack config --scope=user add config:install_tree:/dev/shm/spack-stage
 
 spack env create -d ./spack-env
 # add local repository with current sirius recipe
@@ -25,6 +27,6 @@ spack -e ./spack-env concretize
 spack -e ./spack-env install
 
 # the tar pipe below expects a relative path
-builddir=$(spack -e ./spack-env location -b sirius)
+# builddir=$(spack -e ./spack-env location -b sirius)
 # create a symlink to spack build directory (keep in artifacts)
-tar -cf builddir.tar $builddir
+tar -cf builddir.tar /dev/shm/spack-stage
