@@ -13,7 +13,7 @@
 #endif
 
 #if defined(SIRIUS_DLAF)
-#include <dlaf_c/init.h>
+#include "core/la/dlaf.hpp"
 #endif
 
 namespace sirius {
@@ -104,8 +104,13 @@ Eigensolver_elpa::solve(ftn_int matrix_size__, ftn_int nev__, la::dmatrix<double
 
     auto w = mph.get_unique_ptr<double>(matrix_size__);
 
+#if ELPA_API_VERSION < 20250131
     elpa_generalized_eigenvectors_d(handle, A__.at(memory_t::host), B__.at(memory_t::host), w.get(),
                                     Z__.at(memory_t::host), 0, &error);
+#else
+    elpa_generalized_eigenvectors(handle, A__.at(memory_t::host), B__.at(memory_t::host), w.get(),
+                                  Z__.at(memory_t::host), 0, &error);
+#endif
 
     if (error != ELPA_OK) {
         elpa_deallocate(handle, &error);
@@ -168,8 +173,13 @@ Eigensolver_elpa::solve(ftn_int matrix_size__, ftn_int nev__, la::dmatrix<std::c
 
     auto w = mph.get_unique_ptr<double>(matrix_size__);
 
+#if ELPA_API_VERSION < 20250131
     elpa_generalized_eigenvectors_dc(handle, A__.at(memory_t::host), B__.at(memory_t::host), w.get(),
                                      Z__.at(memory_t::host), 0, &error);
+#else
+    elpa_generalized_eigenvectors(handle, A__.at(memory_t::host), B__.at(memory_t::host), w.get(),
+                                  Z__.at(memory_t::host), 0, &error);
+#endif
 
     if (error != ELPA_OK) {
         elpa_deallocate(handle, &error);
@@ -328,18 +338,10 @@ Eigensolver_elpa::solve(ftn_int matrix_size__, la::dmatrix<std::complex<double>>
 
 #if defined(SIRIUS_DLAF)
 
-void
-Eigensolver_dlaf::initialize()
-{
-    const char* pika_argv[] = {"sirius"};
-    const char* dlaf_argv[] = {"sirius"};
-    dlaf_initialize(1, pika_argv, 1, dlaf_argv);
-}
-
 void
 Eigensolver_dlaf::finalize()
 {
-    dlaf_finalize();
+    dlaf::finalize();
 }
 
 #endif
