@@ -28,8 +28,7 @@
 #endif
 
 #if defined(SIRIUS_DLAF)
-#include <dlaf_c/eigensolver/eigensolver.h>
-#include <dlaf_c/eigensolver/gen_eigensolver.h>
+#include "core/la/dlaf.hpp"
 #endif
 
 namespace sirius {
@@ -1241,8 +1240,6 @@ class Eigensolver_dlaf : public Eigensolver
     {
     }
 
-    static void
-    initialize();
     static void
     finalize();
 
@@ -1252,30 +1249,7 @@ class Eigensolver_dlaf : public Eigensolver
     int
     solve_(ftn_int matrix_size__, dmatrix<T>& A__, real_type<T>* eval__, dmatrix<T>& Z__)
     {
-        DLAF_descriptor desca{
-                matrix_size__, matrix_size__, A__.bs_row(), A__.bs_col(), 0, 0, 0, 0, static_cast<int>(A__.ld())};
-        DLAF_descriptor descz{
-                matrix_size__, matrix_size__, Z__.bs_row(), Z__.bs_col(), 0, 0, 0, 0, static_cast<int>(Z__.ld())};
-
-        if (std::is_same_v<T, std::complex<double>>) {
-            return dlaf_hermitian_eigensolver_z(A__.blacs_grid().context(), 'L',
-                                                reinterpret_cast<std::complex<double>*>(A__.at(memory_t::host)), desca,
-                                                reinterpret_cast<double*>(eval__),
-                                                reinterpret_cast<std::complex<double>*>(Z__.at(memory_t::host)), descz);
-        } else if (std::is_same_v<T, std::complex<float>>) {
-            return dlaf_hermitian_eigensolver_c(A__.blacs_grid().context(), 'L',
-                                                reinterpret_cast<std::complex<float>*>(A__.at(memory_t::host)), desca,
-                                                reinterpret_cast<float*>(eval__),
-                                                reinterpret_cast<std::complex<float>*>(Z__.at(memory_t::host)), descz);
-        } else if (std::is_same_v<T, double>) {
-            return dlaf_symmetric_eigensolver_d(
-                    A__.blacs_grid().context(), 'L', reinterpret_cast<double*>(A__.at(memory_t::host)), desca,
-                    reinterpret_cast<double*>(eval__), reinterpret_cast<double*>(Z__.at(memory_t::host)), descz);
-        } else if (std::is_same_v<T, float>) {
-            return dlaf_symmetric_eigensolver_s(
-                    A__.blacs_grid().context(), 'L', reinterpret_cast<float*>(A__.at(memory_t::host)), desca,
-                    reinterpret_cast<float*>(eval__), reinterpret_cast<float*>(Z__.at(memory_t::host)), descz);
-        }
+        return dlaf::hermitian_eigensolver(matrix_size__, A__, eval__, Z__);
     }
 
     /// wrapper for solving a standard eigen-value problem for all eigen-pairs.
@@ -1360,36 +1334,7 @@ class Eigensolver_dlaf : public Eigensolver
     int
     solve_(ftn_int matrix_size__, dmatrix<T>& A__, dmatrix<T>& B__, real_type<T>* eval__, dmatrix<T>& Z__)
     {
-        DLAF_descriptor desca{
-                matrix_size__, matrix_size__, A__.bs_row(), A__.bs_col(), 0, 0, 0, 0, static_cast<int>(A__.ld())};
-        DLAF_descriptor descb{
-                matrix_size__, matrix_size__, B__.bs_row(), B__.bs_col(), 0, 0, 0, 0, static_cast<int>(B__.ld())};
-        DLAF_descriptor descz{
-                matrix_size__, matrix_size__, Z__.bs_row(), Z__.bs_col(), 0, 0, 0, 0, static_cast<int>(Z__.ld())};
-
-        if (std::is_same_v<T, std::complex<double>>) {
-            return dlaf_hermitian_generalized_eigensolver_z(
-                    A__.blacs_grid().context(), 'L', reinterpret_cast<std::complex<double>*>(A__.at(memory_t::host)),
-                    desca, reinterpret_cast<std::complex<double>*>(B__.at(memory_t::host)), descb,
-                    reinterpret_cast<double*>(eval__), reinterpret_cast<std::complex<double>*>(Z__.at(memory_t::host)),
-                    descz);
-        } else if (std::is_same_v<T, std::complex<float>>) {
-            return dlaf_hermitian_generalized_eigensolver_c(
-                    A__.blacs_grid().context(), 'L', reinterpret_cast<std::complex<float>*>(A__.at(memory_t::host)),
-                    desca, reinterpret_cast<std::complex<float>*>(B__.at(memory_t::host)), descb,
-                    reinterpret_cast<float*>(eval__), reinterpret_cast<std::complex<float>*>(Z__.at(memory_t::host)),
-                    descz);
-        } else if (std::is_same_v<T, double>) {
-            return dlaf_symmetric_generalized_eigensolver_d(
-                    A__.blacs_grid().context(), 'L', reinterpret_cast<double*>(A__.at(memory_t::host)), desca,
-                    reinterpret_cast<double*>(B__.at(memory_t::host)), descb, reinterpret_cast<double*>(eval__),
-                    reinterpret_cast<double*>(Z__.at(memory_t::host)), descz);
-        } else if (std::is_same_v<T, float>) {
-            return dlaf_symmetric_generalized_eigensolver_s(
-                    A__.blacs_grid().context(), 'L', reinterpret_cast<float*>(A__.at(memory_t::host)), desca,
-                    reinterpret_cast<float*>(A__.at(memory_t::host)), descb, reinterpret_cast<float*>(eval__),
-                    reinterpret_cast<float*>(Z__.at(memory_t::host)), descz);
-        }
+        return dlaf::hermitian_generalized_eigensolver(matrix_size__, A__, B__, eval__, Z__);
     }
 
     /// wrapper for solving a generalized eigen-value problem for all eigen-pairs.
