@@ -1,21 +1,10 @@
-// Copyright (c) 2013-2015 Anton Kozhevnikov, Thomas Schulthess
-// All rights reserved.
-//
-// Redistribution and use in source and binary forms, with or without modification, are permitted provided that
-// the following conditions are met:
-//
-// 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
-//    following disclaimer.
-// 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions
-//    and the following disclaimer in the documentation and/or other materials provided with the distribution.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
-// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-// PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
-// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
 
 /** \file matching_coefficients.hpp
  *
@@ -126,17 +115,17 @@ class Matching_coefficients // TODO: compute on GPU
             std::vector<std::complex<double>> ylm(lmmax_apw);
 
             #pragma omp for
-            for (int i = 0; i < gkvec_.count(); i++) {
-                auto gkvec_cart = gkvec_.gkvec_cart<index_domain_t::local>(i);
+            for (auto it : gkvec_) {
+                auto gkvec_cart = gkvec_.gkvec_cart(it.igloc);
                 /* get r, theta, phi */
-                auto vs       = r3::spherical_coordinates(gkvec_cart);
-                gkvec_len_[i] = vs[0];
+                auto vs = r3::spherical_coordinates(gkvec_cart);
 
+                gkvec_len_[it.igloc] = vs[0];
                 /* get spherical harmonics */
                 sf::spherical_harmonics(lmax_apw, vs[1], vs[2], &ylm[0]);
 
                 for (int lm = 0; lm < lmmax_apw; lm++) {
-                    gkvec_ylm_(i, lm) = ylm[lm];
+                    gkvec_ylm_(it.igloc, lm) = ylm[lm];
                 }
             }
         }
@@ -201,9 +190,9 @@ class Matching_coefficients // TODO: compute on GPU
         int iat = type.id();
 
         std::vector<std::complex<double>> phase_factors(gkvec_.count());
-        for (int i = 0; i < gkvec_.count(); i++) {
-            double phase     = twopi * dot(gkvec_.template gkvec<index_domain_t::local>(i), atom__.position());
-            phase_factors[i] = std::exp(std::complex<double>(0, phase));
+        for (auto it : gkvec_) {
+            double phase            = twopi * dot(gkvec_.gkvec(it.igloc), atom__.position());
+            phase_factors[it.igloc] = std::exp(std::complex<double>(0, phase));
         }
 
         const double eps{0.1};
