@@ -148,6 +148,14 @@ Potential::Potential(Simulation_context& ctx__)
         U_ = std::make_unique<Hubbard>(ctx_);
     }
 
+    if (ctx_.cfg().parameters().dftd3_correction()) {
+        dftd3_ = std::make_unique<dftd3>(new dftd3(ctx_, unit_cell_));
+    }
+
+    if (ctx_.cfg().parameters().dftd4_correction()) {
+        dftd4_ = std::make_unique<dftd4>(new dftd4(ctx_, unit_cell_));
+    }
+
     update();
 }
 
@@ -227,6 +235,16 @@ Potential::update()
             xc.vdw_update_unit_cell(ctx_.spfft<double>(), ctx_.unit_cell().lattice_vectors());
         }
     }
+
+    // dftd3 depends on the unit cell
+    if (ctx_.cfg().parameters().dftd3_correction()) {
+        dftd3_ctx().update_dftd3_ctx();
+    }
+
+    // dftd3 depends on the unit cell
+    if (ctx_.cfg().parameters().dftd4_correction()) {
+        dftd4_ctx().update_dftd4_ctx();
+    }
 }
 
 bool
