@@ -21,10 +21,8 @@
 #include "core/fft/fft.hpp"
 #if defined(SIRIUS_USE_VDWXC)
 #include <vdwxc.h>
-#if SIRIUS_HAVE_VDWXC_MPI
 #include <vdwxc_mpi.h>
 #endif
-#endif
 
 namespace sirius {
 
@@ -37,7 +35,10 @@ class XC_functional : public XC_functional_base
 #if defined(SIRIUS_USE_VDWXC)
     vdwxc_data handler_vdw_{nullptr};
     bool vdw_functional_{false};
+    int func_{-1};
+    int num_spins_{-1};
 #endif
+
     /* forbid copy constructor */
     XC_functional(const XC_functional& src) = delete;
 
@@ -51,7 +52,6 @@ class XC_functional : public XC_functional_base
                   const std::string libxc_name__, int num_spins__)
         : XC_functional_base(libxc_name__, num_spins__)
     {
-
 #if defined(SIRIUS_USE_VDWXC)
         /* return immediately if the functional_base class is initialized */
         if (this->libxc_initialized_) {
@@ -64,8 +64,6 @@ class XC_functional : public XC_functional_base
         test      = test || (libxc_name_ == "XC_FUNC_VDWDF2");
         test      = test || (libxc_name_ == "XC_FUNC_VDWDFCX");
 
-        int func_ = -1;
-
         if (libxc_name__ == "XC_FUNC_VDWDF") {
             func_ = FUNC_VDWDF;
         }
@@ -78,40 +76,14 @@ class XC_functional : public XC_functional_base
             func_ = FUNC_VDWDFCX;
         }
 
+        num_spins_ = num_spins__;
+
         if (test) {
-            if (num_spins__ == 1) {
-                // non magnetic case
-                handler_vdw_ = vdwxc_new(func_);
-            } else {
-                // magnetic case
-                handler_vdw_ = vdwxc_new_spin(func_);
-            }
-
-            if (!handler_vdw_) {
-                std::stringstream s;
-                s << "VDW functional lib could not be initialized";
-                RTE_THROW(s);
-            }
-
-            double v1[3] = {lattice_vectors__(0, 0), lattice_vectors__(1, 0), lattice_vectors__(2, 0)};
-            double v2[3] = {lattice_vectors__(0, 1), lattice_vectors__(1, 1), lattice_vectors__(2, 1)};
-            double v3[3] = {lattice_vectors__(0, 2), lattice_vectors__(1, 2), lattice_vectors__(2, 2)};
-            vdwxc_set_unit_cell(handler_vdw_, fft__.dim_x(), fft__.dim_y(), fft__.dim_z(), v1[0], v1[1], v1[2], v2[0],
-                                v2[1], v2[2], v3[0], v3[1], v3[2]);
-            if (mpi::Communicator(fft__.communicator()).size() == 1) {
-                vdwxc_init_serial(handler_vdw_);
-            } else {
-#if SIRIUS_HAVE_VDWXC_MPI
-                vdwxc_init_mpi(handler_vdw_, fft__.communicator());
-#else
-                vdwxc_init_serial(handler_vdw_);
-#endif
-            }
-            vdw_functional_ = true;
-            return;
+            create_handler(fft__, lattice_vectors__);
         } else {
             /* it means that the functional does not exist either in vdw or xc libraries */
             std::stringstream s;
+
             s << "XC functional " << libxc_name__ << " is unknown";
             RTE_THROW(s);
         }
@@ -119,9 +91,11 @@ class XC_functional : public XC_functional_base
         if (this->libxc_initialized_) {
             return;
         } else {
-            /* it means that the functional does not exist either in vdw or xc libraries */
+            /* it means that the functional does not exist either in vdw or xc
+               libraries or that SIRIUS is not compiled with vdwxc support */
             std::stringstream s;
             s << "XC functional " << libxc_name__ << " is unknown";
+
             RTE_THROW(s);
         }
 #endif /* SIRIUS_USE_VDWXC */
@@ -131,8 +105,11 @@ class XC_functional : public XC_functional_base
         : XC_functional_base(std::move(src__))
     {
 #if defined(SIRIUS_USE_VDWXC)
-        this->handler_vdw_    = src__.handler_vdw_;
+        this->handler_vdw_    = std::move(src__.handler_vdw_);
         this->vdw_functional_ = src__.vdw_functional_;
+        this->func_           = src__.func_;
+        this->num_spins_      = src__.num_spins_;
+        src__.handler_vdw_    = nullptr;
         src__.vdw_functional_ = false;
 #endif
     }
@@ -140,9 +117,10 @@ class XC_functional : public XC_functional_base
     ~XC_functional()
     {
 #if defined(SIRIUS_USE_VDWXC)
-        if (this->vdw_functional_) {
+        if (handler_vdw_) {
             vdwxc_finalize(&this->handler_vdw_);
             this->vdw_functional_ = false;
+            this->handler_vdw_    = nullptr;
             return;
         }
 #endif
@@ -198,6 +176,13 @@ class XC_functional : public XC_functional_base
             double v2[3] = {lattice_vectors__(0, 1), lattice_vectors__(1, 1), lattice_vectors__(2, 1)};
             double v3[3] = {lattice_vectors__(0, 2), lattice_vectors__(1, 2), lattice_vectors__(2, 2)};
 
+            // we need to add a test for checking that the fft parameters have
+            // not changed. Right now I assume that fft box can change and I
+            // recreate the handler from scratch
+
+            vdwxc_finalize(&this->handler_vdw_);
+            create_handler(fft__, lattice_vectors__);
+
             vdwxc_set_unit_cell(handler_vdw_, fft__.dim_x(), fft__.dim_y(), fft__.dim_z(), v1[0], v1[1], v1[2], v2[0],
                                 v2[1], v2[2], v3[0], v3[1], v3[2]);
         }
@@ -224,6 +209,7 @@ class XC_functional : public XC_functional_base
         if (!is_vdw()) {
             RTE_THROW("Error wrong vdw XC");
         }
+
         energy__[0] = vdwxc_calculate(handler_vdw_, rho, sigma, vrho, vsigma);
     }
 
@@ -240,8 +226,42 @@ class XC_functional : public XC_functional_base
                                            vsigma_up, vsigma_down);
     }
 #endif
-};
+  private:
+    void
+    create_handler(spfft::Transform const& fft__, r3::matrix<double> const& lattice_vectors__)
+    {
+#if defined(SIRIUS_USE_VDWXC)
+        if (num_spins_ == 1) {
+            // non magnetic case
+            handler_vdw_ = vdwxc_new(func_);
+        } else {
+            // magnetic case
+            handler_vdw_ = vdwxc_new_spin(func_);
+        }
 
+        if (!handler_vdw_) {
+            std::stringstream s;
+            s << "VDW functional lib could not be initialized";
+            RTE_THROW(s);
+        }
+
+        double v1[3] = {lattice_vectors__(0, 0), lattice_vectors__(1, 0), lattice_vectors__(2, 0)};
+        double v2[3] = {lattice_vectors__(0, 1), lattice_vectors__(1, 1), lattice_vectors__(2, 1)};
+        double v3[3] = {lattice_vectors__(0, 2), lattice_vectors__(1, 2), lattice_vectors__(2, 2)};
+
+        vdwxc_set_unit_cell(handler_vdw_, fft__.dim_x(), fft__.dim_y(), fft__.dim_z(), v1[0], v1[1], v1[2], v2[0],
+                            v2[1], v2[2], v3[0], v3[1], v3[2]);
+
+        if (mpi::Communicator(fft__.communicator()).size() == 1) {
+            vdwxc_init_serial(handler_vdw_);
+        } else {
+            vdwxc_init_mpi(handler_vdw_, fft__.communicator());
+        }
+        vdw_functional_ = true;
+#endif /* SIRIUS_USE_VDWXC */
+        return;
+    }
+};
 } // namespace sirius
 
 #endif // __XC_FUNCTIONAL_H__
