@@ -121,9 +121,6 @@ initialize(bool call_mpi_init__ = true)
 #endif
 #if defined(SIRIUS_ELPA)
     la::Eigensolver_elpa::initialize();
-#endif
-#if defined(SIRIUS_DLAF)
-    la::Eigensolver_dlaf::initialize();
 #endif
     /* for the fortran interface to blas/lapack */
     RTE_ASSERT(sizeof(int) == 4);
@@ -181,6 +178,11 @@ finalize(bool call_mpi_fin__ = true, bool reset_device__ = true, bool fftw_clean
         printf("energy     : %9.2f Joules\n", e * nn / Communicator::world().size());
         printf("energy_acc : %9.2f Joules\n", e_acc * nn / Communicator::world().size());
     }
+#endif
+#if defined(SIRIUS_DLAF)
+    // Finalization frees DLA-Future grids
+    // It needs to be called before finalizing MPI
+    la::Eigensolver_dlaf::finalize();
 #endif
     auto rank = mpi::Communicator::world().rank();
     if (call_mpi_fin__) {
@@ -188,9 +190,6 @@ finalize(bool call_mpi_fin__ = true, bool reset_device__ = true, bool fftw_clean
     }
 #if defined(SIRIUS_ELPA)
     la::Eigensolver_elpa::finalize();
-#endif
-#if defined(SIRIUS_DLAF)
-    la::Eigensolver_dlaf::finalize();
 #endif
     if (acc::num_devices() && reset_device__) {
         acc::reset();
